@@ -1,17 +1,9 @@
+//!# Interface
 //!
-//!# ToDo List
-//!
-//!Implement DROP INDEX, ALTER TABLE, fully implement CREATE INDEX.
-//!
-//!Sort out error handling for PARSEINT etc.
-//!
-//!Work on improving/testing SQL code, browse schema, float I/O. Login.
-//!
-//!# Features
-//!
-//! This crate supports two cargo features.
-//! - `builtin` : Allows extra SQL builtin functions to be defined.
-//! - `max` : Exposes maximal interface, including all internal modules (default).
+//!The method [Database]::run (or alternatively Database::run_timed) is called to execute an SQL query.
+//!This takes a [Query] parameter which accumulates SELECT results and which also has methods
+//!for accessing the environment and controlling output. Custom builtin functions have access to the query
+//!which can be downcast if ncessary.   
 //!
 //!# Examples
 //! ```
@@ -45,6 +37,12 @@
 //!
 //![See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example (Axum webserver with ARGON hash function).
 //!
+//!# Features
+//!
+//! This crate supports two cargo features.
+//! - `builtin` : Allows extra SQL builtin functions to be defined.
+//! - `max` : Exposes maximal interface, including all internal modules (default).
+//!
 //!# General Design of Database
 //!
 //!SortedFile stores fixed size Records in a tree of Pages.
@@ -61,6 +59,17 @@
 //!When a page becomes too big, it is split into two pages.
 //!
 //!Each page is implemented as a binary tree ( so there is a tree of trees ).
+//!
+//!# ToDo List
+//!
+//!Implement DROP INDEX, ALTER TABLE, fully implement CREATE INDEX.
+//!
+//!Consider replication/backup/durability issues [Here](https://en.wikipedia.org/wiki/Durability_(database_systems))
+//!
+//!Sort out error handling for PARSEINT etc.
+//!
+//!Work on improving/testing SQL code, browse schema, float I/O. Login.
+//!
 
 pub use crate::{
     genquery::{GenQuery, Part},
@@ -102,7 +111,7 @@ use crate::{
     value::*,
 };
 
-use parking_lot::{Mutex, RwLock};
+use std::sync::{Mutex, RwLock};
 use std::{
     cell::{Cell, RefCell},
     cmp::Ordering,
